import { ElRadioGroup, ElRadio, ElCheckboxGroup, ElCheckbox } from 'element-plus'
import { useFormInput, useOptions } from '@cip/components/hooks/form-input'
import { formInputProps } from '../../form-input-props'
import { computed, h } from 'vue'
import { isArray } from '@cip/utils/util'
export default {
  props: formInputProps,
  emits: ['update:modelValue'],
  setup (props, context) {
    const { width, ...formInput } = useFormInput(props, context)
    const { emitInput } = formInput
    const { options } = useOptions(props, false, formInput.emitInput)
    const display = computed(() => {
      return props.config?.display ?? 'inline-block'
    })
    const multiple = computed(() => {
      return props.config?.multiple ?? false
    })

    const selectComponent = multiple.value ? ElCheckbox : ElRadio
    const selectComponentGroup = multiple.value ? ElCheckboxGroup : ElRadioGroup

    const radioItem = (val) => {
      if (val.url) {
        return h(selectComponent, { label: val?.value ?? 0, style: { display: display.value } }, {
          default: () => h('img', { src: val?.url, width: val?.width ?? 20, style: 'vertical-align: middle;' })
        })
      }
    }

    const radioItems = () => options.value.map(radioItem)
    const radioDefaultSlots = () => {
      return radioItems()
    }

    const transValue = computed({
      get () {
        const value = props.modelValue
        if (!multiple.value) {
          return value ?? ''
        }
        if (isArray(value)) {
          return value ?? []
        }
        return value ? value.split(props.config.splitKey || ',') : []
      }
    })

    return () => {
      return h(selectComponentGroup, {
        ...context.attrs,
        ...formInput,
        style: { width },
        disabled: props.disabled,
        modelValue: transValue.value,
        'onUpdate:modelValue': emitInput
      },
      { default: radioDefaultSlots })
    }
  }
}
