import { computed, defineComponent, h, ref, watchEffect } from 'vue'
import { formInputProps } from '../../form-input-props'
import BasicSelect from '../../basic/select'
import BasicCheckBox from '../../basic/checkbox'
import BasicRadio from '../../basic/radio'
import { DictionaryItem } from '@/api'
// 逻辑简化版接口select
export default defineComponent({
  name: 'BasicDataDictionary',
  props: formInputProps,
  emits: ['update:modelValue', 'update:otherValue'],
  setup (props, context) {
    const inputRef = ref()
    watchEffect(() => {
      if (props.config.dictionaryCode) {
        // eslint-disable-next-line no-unused-expressions
        inputRef.value?.getOptions()
      }
    })
    const asyncOptions = async () => {
      if (!props.config.dictionaryCode) return []
      const { data } = await DictionaryItem.list({ dictionaryCode: props.config.dictionaryCode })
      return data || []
    }
    const rewriteConfig = computed(() => {
      const originConfig = props.config
      originConfig.asyncOptions = asyncOptions
      return originConfig
    })
    const getComponentByViewType = (viewType = 'select') => {
      switch (viewType) {
        case 'radio': return BasicRadio
        case 'checkbox': return BasicCheckBox
        default: return BasicSelect
      }
    }
    return () => h(getComponentByViewType(props.config.viewType), {
      ref: inputRef,
      fieldKey: props.fieldKey,
      modelValue: props.modelValue,
      otherValue: props.otherValue,
      config: rewriteConfig.value,
      model: props.model,
      rules: props.rules,
      dependOnValues: props.dependOnValues,
      disabled: props.disabled,
      showTemplate: props.showTemplate,
      'onUpdate:modelValue' (val) {
        context.emit('update:modelValue', val)
      },
      'onUpdate:otherValue' (val) {
        context.emit('update:otherValue', val)
      }
    })
  }
})
